/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.activation.domain;

import java.io.Serializable;
import java.util.UUID;

import javax.persistence.Column;
import javax.persistence.Embeddable;

import se.vgregion.dao.domain.patterns.valueobject.AbstractValueObject;

@Embeddable
public class ActivationCode extends AbstractValueObject implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * Constructor.
     */
    public ActivationCode() {
        // To make Hibernate happy
    }

    @Column(name = "activationCode")
    private String value;

    /**
     * Constructor.
     *
     * @param value value
     */
    public ActivationCode(String value) {
        this.value = value;
    }

    public String getValue() {
        return value;
    }

    /**
     * Generate an <code>ActivationCode</code> with random value.
     *
     * @return A new <code>ActivationCode</code>.
     */
    public static ActivationCode generate() {
        return new ActivationCode(UUID.randomUUID().toString());
    }
}
